@@ -923,7 +923,7 @@ int main(int argc, char **argv)
 						 "(C) 1998-2001, Stefan Westerfeld",
 						 I18N_NOOP("The analog real-time synthesizer graphical design tool."),
 						 "http://www.arts-project.org/",
-						 "submit@bugs.kde.org");
+						 "submit@bugs.trinitydesktop.org");
 
 	aboutData.addAuthor("Stefan Westerfeld", I18N_NOOP("Author"), "stefan@twc.de");
 	aboutData.addCredit("Waldo Bastian", 0, "bastian@kde.org");
